
.include	"Definitionen.inc"

;****************************** Verktor-Liste ****************************

.CSEG
                rjmp    Reset


;****************************** Programm-Beginn **********************

;*********************************************************************
;  Initialisierungsroutine
;*********************************************************************

.ORG	INT_VECTORS_SIZE

; Hardware initialisieren

Reset:  ldi     TEMP_A,low(RAMEND)          ; Stack an das interne Ram-Ende
        out     SPL,TEMP_A
        ldi     TEMP_A,high(RAMEND)
        out     SPH,TEMP_A

; Externer Ram ein ***************************************************

		ldi		TEMP_A,(1<<SRE)
		out		MCUCR,TEMP_A

; Port A *************************************************************

        ser     TEMP_A						; Alle PullUp ein bzw. Ausgang auf High
        out     PORTA,TEMP_A
		clr		TEMP_A						; Alles Eingang
        out     DDRA,TEMP_A

; Port B *************************************************************

        ser		TEMP_A						; Alle PullUp ein bzw. Ausgang auf High
		out     PORTB,TEMP_A
        out     DDRB,TEMP_A					; LED
		clr		TEMP_A

; Port C *************************************************************

        ser     TEMP_A						; Alle PullUp ein bzw. Ausgang auf High
        out     PORTC,TEMP_A
		clr		TEMP_A						
        out     DDRC,TEMP_A	

; Port D *************************************************************

		ser		TEMP_A						; Alle PullUp ein bzw. Ausgang auf High
        out     PORTD,TEMP_A
        clr		TEMP_A
		out     DDRD,TEMP_A 				; Tasten

; Port E *************************************************************

		ser		TEMP_A						; Alle PullUp ein bzw. Ausgang auf High
        out     PORTE,TEMP_A
		clr		TEMP_A						; Alles Eingang
        out     DDRE,TEMP_A

; UART ***************************************************************

        ldi     TEMP_A,high(UART_BAUD_SELECT)
        out     UBRRH,TEMP_A
        ldi     TEMP_A,low(UART_BAUD_SELECT)
        out     UBRRL,TEMP_A
        ldi     TEMP_A,(1<<TXEN)
        out     UCSRB,TEMP_A
        ldi     TEMP_A,(1<<URSEL)|(1<<UCSZ1)|(1<<UCSZ0)
        out     UCSRC,TEMP_A

;*********************************************************************				 

; Software initialisieren
		load_p	Z,(2*debug_reset)
		rcall	send_text		
		rcall	send_newline

		ldi		SP,$00
		rcall	load_sid					; Ladeadresse in PC 6510 (Y)

		load_p	Z,STACK_END
		ldi		TEMP_A,$FF

stack_clear_loop:		
		st		Z+,TEMP_A
		tst		ZL
		brne	stack_clear_loop

		push	YL
		push	YH
		mov		XL,YL
		mov		XH,YH
		load_p	Y,512
		rcall	debug_32bit_tab
		pop		YH
		pop		YL
							 
;*********************************************************************
;  Main-Loop
;*********************************************************************
main:

befehls_decoder:
/*      hier knnten noch 4 Takte gespart werden, falls irgendwo die 32 Takte fr 2-6510-Zyklen-Befehle nicht reichen.
		alle Adress-Labels in der Tabelle mten dann mit rjmp label ersetzt werden.
		Die Tabelle mu dann vermutlich nher am Decoder included werden, wegen +- 2k Sprungweite

		clr		ZH					; #1#
		ld		ZL,Y+				; #2# 6510 Befehl holen
		lsl		ZL					; #1#
		rol		ZH					; #1#
		lsl		ZL					; #1#
		rol		ZH					; #1#
		ori		ZH,high(2*befehle)	; #1#
		ijmp						; #2# + 2 fr rjmp in Tabelle -> 12 Takte bis zum Befehl	
*/			

		rcall	debug_6510

key_up_loop:
		in		TEMP_A,PIND
		andi	TEMP_A,0b00000001
		cpi		TEMP_A,0b00000001
		brne	key_up_loop

key_down_loop:
		in		TEMP_A,PIND
		andi	TEMP_A,0b00000001
		brne	key_down_loop

		ld		ZL,Y+				; #2# 6510 Befehl holen
		ldi		ZH,high(2*befehle)	; #1#
		sbrc	ZL,7				; #1# bei no Skip, #2# bei Skip
		inc		ZH					; #1# = 2 bei no Skip
		lsl		ZL					; #1# *2

		lpm		XL,Z+				; #3#
		lpm		XH,Z				; #3#
		mov		ZL,XL				; #1#
		mov		ZH,XH				; #1#
		ijmp						; #2# Sprung zum Befehl 16 Takte
									; Schleife komplett 16 Takte. Bei 16MHz 32 Takte -> 16 fr Befehl...
unbekannt:
		rcall	debug_6510

unbekannt_loop:
		rjmp	unbekannt_loop

; Aufruf rcall #3#
zyklus_1:
		nop

warten_15:
		nop

warten_14:
		nop

warten_13:
		nop

warten_12:
		nop

warten_11:
		nop

warten_10:
		nop

warten_9:
		nop

warten_8:
		nop

warten_7:
		ret			; #4#


;*********************************************************************
;  Ende Main-Loop
;*********************************************************************

;***************************************************************************

.include	"befehle_a.inc"
.include	"befehle_b.inc"
.include	"befehle_c.inc"
.include	"befehle_d.inc"
.include	"befehle_e.inc"
.include	"befehle_i.inc"
.include	"befehle_j.inc"
.include	"befehle_l.inc"
.include	"befehle_n.inc"
.include	"befehle_o.inc"
.include	"befehle_p.inc"
.include	"befehle_r.inc"
.include	"befehle_s.inc"
.include	"befehle_t.inc"
.include	"set_flags.inc"

.include	"subroutinen.inc"
.include	"uart.inc"
.include	"debug.inc"

;***************************************************************************
;  Programm Ende 
;***************************************************************************

.include	"tabellen.inc"
